==> kubernetes-model-networking-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1/IngressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IngressSpecFluent<A extends IngressSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildDefaultBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getDefaultBackend();
    public IngressBackend buildDefaultBackend();
    public A withDefaultBackend(IngressBackend defaultBackend);
    public Boolean hasDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackendLike(IngressBackend item);
    public IngressSpecFluent.DefaultBackendNested<A> editDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackendLike(IngressBackend item);
    public String getIngressClassName();
    public A withIngressClassName(String ingressClassName);
    public Boolean hasIngressClassName();
    public A withNewIngressClassName(String arg1);
    public A withNewIngressClassName(StringBuilder arg1);
    public A withNewIngressClassName(StringBuffer arg1);
    public A addToRules(int index,IngressRule item);
    public A setToRules(int index,IngressRule item);
    public A addToRules(IngressRule... items);
    public A addAllToRules(Collection<IngressRule> items);
    public A removeFromRules(IngressRule... items);
    public A removeAllFromRules(Collection<IngressRule> items);
    public A removeMatchingFromRules(Predicate<IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<IngressRule> getRules();
    public List<IngressRule> buildRules();
    public IngressRule buildRule(int index);
    public IngressRule buildFirstRule();
    public IngressRule buildLastRule();
    public IngressRule buildMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public A withRules(List<IngressRule> rules);
    public A withRules(IngressRule... rules);
    public Boolean hasRules();
    public IngressSpecFluent.RulesNested<A> addNewRule();
    public IngressSpecFluent.RulesNested<A> addNewRuleLike(IngressRule item);
    public IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,IngressRule item);
    public IngressSpecFluent.RulesNested<A> editRule(int index);
    public IngressSpecFluent.RulesNested<A> editFirstRule();
    public IngressSpecFluent.RulesNested<A> editLastRule();
    public IngressSpecFluent.RulesNested<A> editMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public A addToTls(int index,IngressTLS item);
    public A setToTls(int index,IngressTLS item);
    public A addToTls(IngressTLS... items);
    public A addAllToTls(Collection<IngressTLS> items);
    public A removeFromTls(IngressTLS... items);
    public A removeAllFromTls(Collection<IngressTLS> items);
    public A removeMatchingFromTls(Predicate<IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<IngressTLS> getTls();
    public List<IngressTLS> buildTls();
    public IngressTLS buildTl(int index);
    public IngressTLS buildFirstTl();
    public IngressTLS buildLastTl();
    public IngressTLS buildMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public A withTls(List<IngressTLS> tls);
    public A withTls(IngressTLS... tls);
    public Boolean hasTls();
    public IngressSpecFluent.TlsNested<A> addNewTl();
    public IngressSpecFluent.TlsNested<A> addNewTlLike(IngressTLS item);
    public IngressSpecFluent.TlsNested<A> setNewTlLike(int index,IngressTLS item);
    public IngressSpecFluent.TlsNested<A> editTl(int index);
    public IngressSpecFluent.TlsNested<A> editFirstTl();
    public IngressSpecFluent.TlsNested<A> editLastTl();
    public IngressSpecFluent.TlsNested<A> editMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public interface DefaultBackendNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressBackendFluent<IngressSpecFluent.DefaultBackendNested<N>> {

        public N and();
        public N endDefaultBackend();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressRuleFluent<IngressSpecFluent.RulesNested<N>> {

        public N and();
        public N endRule();    }


    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressTLSFluent<IngressSpecFluent.TlsNested<N>> {

        public N and();
        public N endTl();    }


}

==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1/IngressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IngressSpecFluent<A extends IngressSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildDefaultBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getDefaultBackend();
    public IngressBackend buildDefaultBackend();
    public A withDefaultBackend(IngressBackend defaultBackend);
    public Boolean hasDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackendLike(IngressBackend item);
    public IngressSpecFluent.DefaultBackendNested<A> editDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackend();
    public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackendLike(IngressBackend item);
    public String getIngressClassName();
    public A withIngressClassName(String ingressClassName);
    public Boolean hasIngressClassName();
    public A withNewIngressClassName(StringBuilder arg1);
    public A withNewIngressClassName(int[] arg1,int arg2,int arg3);
    public A withNewIngressClassName(char[] arg1);
    public A withNewIngressClassName(StringBuffer arg1);
    public A withNewIngressClassName(byte[] arg1,int arg2);
    public A withNewIngressClassName(byte[] arg1);
    public A withNewIngressClassName(char[] arg1,int arg2,int arg3);
    public A withNewIngressClassName(byte[] arg1,int arg2,int arg3);
    public A withNewIngressClassName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIngressClassName(String arg1);
    public A addToRules(int index,IngressRule item);
    public A setToRules(int index,IngressRule item);
    public A addToRules(IngressRule... items);
    public A addAllToRules(Collection<IngressRule> items);
    public A removeFromRules(IngressRule... items);
    public A removeAllFromRules(Collection<IngressRule> items);
    public A removeMatchingFromRules(Predicate<IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<IngressRule> getRules();
    public List<IngressRule> buildRules();
    public IngressRule buildRule(int index);
    public IngressRule buildFirstRule();
    public IngressRule buildLastRule();
    public IngressRule buildMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public A withRules(List<IngressRule> rules);
    public A withRules(IngressRule... rules);
    public Boolean hasRules();
    public IngressSpecFluent.RulesNested<A> addNewRule();
    public IngressSpecFluent.RulesNested<A> addNewRuleLike(IngressRule item);
    public IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,IngressRule item);
    public IngressSpecFluent.RulesNested<A> editRule(int index);
    public IngressSpecFluent.RulesNested<A> editFirstRule();
    public IngressSpecFluent.RulesNested<A> editLastRule();
    public IngressSpecFluent.RulesNested<A> editMatchingRule(Predicate<IngressRuleBuilder> predicate);
    public A addToTls(int index,IngressTLS item);
    public A setToTls(int index,IngressTLS item);
    public A addToTls(IngressTLS... items);
    public A addAllToTls(Collection<IngressTLS> items);
    public A removeFromTls(IngressTLS... items);
    public A removeAllFromTls(Collection<IngressTLS> items);
    public A removeMatchingFromTls(Predicate<IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<IngressTLS> getTls();
    public List<IngressTLS> buildTls();
    public IngressTLS buildTl(int index);
    public IngressTLS buildFirstTl();
    public IngressTLS buildLastTl();
    public IngressTLS buildMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public A withTls(List<IngressTLS> tls);
    public A withTls(IngressTLS... tls);
    public Boolean hasTls();
    public IngressSpecFluent.TlsNested<A> addNewTl();
    public IngressSpecFluent.TlsNested<A> addNewTlLike(IngressTLS item);
    public IngressSpecFluent.TlsNested<A> setNewTlLike(int index,IngressTLS item);
    public IngressSpecFluent.TlsNested<A> editTl(int index);
    public IngressSpecFluent.TlsNested<A> editFirstTl();
    public IngressSpecFluent.TlsNested<A> editLastTl();
    public IngressSpecFluent.TlsNested<A> editMatchingTl(Predicate<IngressTLSBuilder> predicate);
    public interface DefaultBackendNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressBackendFluent<IngressSpecFluent.DefaultBackendNested<N>> {

            public N and();
            public N endDefaultBackend();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressRuleFluent<IngressSpecFluent.RulesNested<N>> {

            public N and();
            public N endRule();    }


    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IngressTLSFluent<IngressSpecFluent.TlsNested<N>> {

            public N and();
            public N endTl();    }


}
